@@ -1,5 +1,5 @@
 /**
- * Copyright 2006-2015 the original author or authors.
+ * Copyright 2006-2017 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,14 +15,18 @@
  */
 package org.objenesis.instantiator.basic;
 
+import org.objenesis.instantiator.annotations.Instantiator;
+import org.objenesis.instantiator.annotations.Typology;
+
 /**
  * Instantiates a class by grabbing the no-args constructor, making it accessible and then calling
  * Constructor.newInstance(). Although this still requires no-arg constructors, it can call
  * non-public constructors (if the security manager allows it).
- * 
+ *
  * @author Joe Walnes
  * @see org.objenesis.instantiator.ObjectInstantiator
  */
+@Instantiator(Typology.NOT_COMPLIANT)
 public class AccessibleInstantiator<T> extends ConstructorInstantiator<T> {
 
    public AccessibleInstantiator(Class<T> type) {
