@@ -1,5 +1,5 @@
 /**
- * Copyright 2006-2015 the original author or authors.
+ * Copyright 2006-2017 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,12 +17,15 @@ package org.objenesis.instantiator.basic;
 
 import org.objenesis.ObjenesisException;
 import org.objenesis.instantiator.ObjectInstantiator;
+import org.objenesis.instantiator.annotations.Instantiator;
+import org.objenesis.instantiator.annotations.Typology;
 
 /**
  * The instantiator that always throws an exception. Mainly used for tests
- * 
+ *
  * @author Henri Tremblay
  */
+@Instantiator(Typology.NOT_COMPLIANT)
 public class FailingInstantiator<T> implements ObjectInstantiator<T> {
 
    public FailingInstantiator(Class<T> type) {
