@@ -1,5 +1,5 @@
 /**
- * Copyright 2006-2016 the original author or authors.
+ * Copyright 2006-2017 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,12 +16,15 @@
 package org.objenesis.instantiator.basic;
 
 import org.objenesis.instantiator.ObjectInstantiator;
+import org.objenesis.instantiator.annotations.Instantiator;
+import org.objenesis.instantiator.annotations.Typology;
 
 /**
  * The instantiator that always return a null instance
- * 
+ *
  * @author Henri Tremblay
  */
+@Instantiator(Typology.NOT_COMPLIANT)
 public class NullInstantiator<T> implements ObjectInstantiator<T> {
 
    public NullInstantiator(Class<T> type) {
