@@ -1,5 +1,5 @@
 /**
- * Copyright 2006-2016 the original author or authors.
+ * Copyright 2006-2017 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,17 +15,22 @@
  */
 package org.objenesis;
 
-import static org.junit.Assert.*;
-
+import org.junit.Rule;
 import org.junit.Test;
+import org.junit.rules.ExpectedException;
 import org.objenesis.instantiator.ObjectInstantiator;
 import org.objenesis.strategy.InstantiatorStrategy;
 
+import static org.junit.Assert.*;
+
 /**
  * @author Henri Tremblay
  */
 public class ObjenesisTest {
 
+   @Rule
+   public ExpectedException expectedException = ExpectedException.none();
+
    @Test
    public final void testObjenesis() {
       Objenesis o = new ObjenesisStd();
@@ -62,6 +67,13 @@ public class ObjenesisTest {
       assertSame(i1, i2);
    }
 
+   @Test
+   public final void testGetInstantiatorOf_primitive() {
+      Objenesis o = new ObjenesisStd();
+      expectedException.expect(IllegalArgumentException.class);
+      o.getInstantiatorOf(long.class);
+   }
+
    @Test
    public final void testToString() {
       Objenesis o = new ObjenesisStd() {};
