@@ -15,20 +15,17 @@
  */
 package org.objenesis.tck;
 
+import java.io.ByteArrayOutputStream;
+import java.io.PrintStream;
+
 import org.junit.Before;
 import org.junit.Test;
 import org.objenesis.Objenesis;
 import org.objenesis.ObjenesisBase;
 import org.objenesis.instantiator.basic.ConstructorInstantiator;
 import org.objenesis.instantiator.basic.FailingInstantiator;
-import org.objenesis.instantiator.basic.NullInstantiator;
 import org.objenesis.strategy.SingleInstantiatorStrategy;
 
-import java.io.ByteArrayOutputStream;
-import java.io.PrintStream;
-import java.util.HashMap;
-import java.util.Map;
-
 import static org.junit.Assert.*;
 
 /**
@@ -49,67 +46,47 @@ public class TextReporterTest {
 
    @Test
    public void testReportsSuccessesInTabularFormat() {
-      Map<String, Object> candidates = new HashMap<String, Object>();
-      candidates.put("candidate A", "A");
-      candidates.put("candidate B", "B");
-      candidates.put("candidate C", "C");
-      Map<String, Object> instantiators = new HashMap<String, Object>();
-
       Objenesis instantiator1 = new ObjenesisBase(new SingleInstantiatorStrategy(
          ConstructorInstantiator.class));
       Objenesis instantiator2 = new ObjenesisBase(new SingleInstantiatorStrategy(
          FailingInstantiator.class));
-      Objenesis instantiator3 = new ObjenesisBase(new SingleInstantiatorStrategy(
-         NullInstantiator.class));
 
-      instantiators.put("instantiator1", instantiator1);
-      instantiators.put("instantiator2", instantiator2);
-      instantiators.put("instantiator3", instantiator3);
+      textReporter.startTests("Some platform", instantiator1, instantiator2);
 
-      textReporter.startTests("Some platform", candidates, instantiators);
+      textReporter.startTest(new Candidate(TCKTest.CandidateA.class, "candidate A",
+         Candidate.CandidateType.STANDARD, Candidate.CandidateType.SERIALIZATION));
+      textReporter.result(Candidate.CandidateType.STANDARD,false);
+      textReporter.result(Candidate.CandidateType.SERIALIZATION, true);
 
-      textReporter.startTest("candidate A", "instantiator1");
-      textReporter.result(false);
-      textReporter.startTest("candidate A", "instantiator2");
-      textReporter.result(false);
-      textReporter.startTest("candidate A", "instantiator3");
-      textReporter.result(true);
+      textReporter.startTest(new Candidate(TCKTest.CandidateB.class, "candidate B", Candidate.CandidateType.STANDARD));
+      textReporter.result(Candidate.CandidateType.STANDARD,true);
 
-      textReporter.startTest("candidate B", "instantiator1");
-      textReporter.result(true);
-      textReporter.startTest("candidate B", "instantiator2");
-      textReporter.result(false);
-      textReporter.startTest("candidate B", "instantiator3");
-      textReporter.result(true);
+      textReporter.startTest(new Candidate(TCKTest.CandidateC.class,"candidate C",
+         Candidate.CandidateType.STANDARD, Candidate.CandidateType.SERIALIZATION));
+      textReporter.exception(Candidate.CandidateType.STANDARD, new RuntimeException("Problem"));
+      textReporter.result(Candidate.CandidateType.SERIALIZATION, false);
 
-      textReporter.startTest("candidate C", "instantiator1");
-      textReporter.exception(new RuntimeException("Problem"));
-      textReporter.startTest("candidate C", "instantiator2");
-      textReporter.result(false);
-      textReporter.startTest("candidate C", "instantiator3");
-      textReporter.result(true);
+      textReporter.startTest(new Candidate(TCKTest.CandidateD.class,"candidate D",
+         Candidate.CandidateType.SERIALIZATION));
+      textReporter.result(Candidate.CandidateType.SERIALIZATION, true);
 
       textReporter.endTests();
 
-      textReporter.printResult(true);
-
       ByteArrayOutputStream expectedSummaryBuffer = new ByteArrayOutputStream();
       PrintStream out = new PrintStream(expectedSummaryBuffer);
       out.println("Running TCK on platform: Some platform");
       out.println();
       out.println("Instantiators used: ");
-      out.println("   instantiator1: ConstructorInstantiator");
-      out.println("   instantiator2: FailingInstantiator");
-      out.println("   instantiator3: NullInstantiator");
+      out.println("   Objenesis standard  : org.objenesis.instantiator.basic.ConstructorInstantiator");
+      out.println("   Objenesis serializer: org.objenesis.instantiator.basic.FailingInstantiator");
       out.println();
-      out.println("Not serializable parent constructor called as expected: Y");
+      out.println("            Objenesis standard   Objenesis serializer");
+      out.println("candidate A n                    Y                   ");
+      out.println("candidate B Y                    N/A                 ");
+      out.println("candidate C n                    n                   ");
+      out.println("candidate D N/A                  Y                   ");
       out.println();
-      out.println("            instantiator1 instantiator2 instantiator3 ");
-      out.println("candidate A n             n             Y             ");
-      out.println("candidate B Y             n             Y             ");
-      out.println("candidate C n             n             Y             ");
-      out.println();
-      out.println("--- FAILED: 5 error(s) occured ---");
+      out.println("--- FAILED: 3 error(s) occurred ---");
       out.println();
 
       assertEquals(expectedSummaryBuffer.toString(), summaryBuffer.toString());
